#!/bin/zsh

# Copyright 2014, 2015, 2017 Paul Hänsch
#
# This file is part of Confetti.
# 
# Confetti is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# 
# Confetti is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
# 
# You should have received a copy of the GNU Affero General Public License
# along with Confetti.  If not, see <http://www.gnu.org/licenses/>. 

. "${_EXEC}/templates/text_frame.sh"
[ -x "${_EXEC}/templates/text_${PAGE}.sh" ] && . "${_EXEC}/templates/text_${PAGE}.sh"

bmfile="${_DATA}/mappings/bookmarks"

cat <<EOF
<!Doctype HTML>

<html>
  <head>
    <title>$(l10n p_${PAGE})</title>
    <meta name="viewport" content="width=device-width">
    <link rel="stylesheet" href="?static=common.css">
    <link rel="stylesheet" href="?static=${PAGE}.css">
  </head>
  <body class="$PAGE">
    <div class="NAVIGATION">
      $(sed -rn '/^[^ ]+\t[^ ]+$/p' "$bmfile" \
        | while read page name; do
        printf '<a href="%s">%s</a>' "${page}" "${name}"
      done)
      <input  id="navigationconfig" class="config" type="checkbox" />
      <label for="navigationconfig">$(l10n nc_edit)</label>
      <form class="config" method="POST" action="?action=update_bookmarks">
        $(for page in "${_EXEC}/pages/"*.sh; do
          page="${page##*/}"
          page="${page%.sh}"
          printf '<a href="?p=%s">%s</a>\n' "${page}" "$(l10n "p_${page}")"
        done |grep -E '^<a href="\?p='"${page_filter}" )
        $(if grep -qF "$REQUEST_URI" "$bmfile"; then
          printf '<input type="hidden" name="bm_url" value="%s" />
                  <input type="text" name="bm_name" value="%s" readonly="readonly" /
                  ><button type="submit" name="submit" value="del">%s</button>' \
                  "$(attribsafe ${REQUEST_URI})" \
                  "$(attribsafe $(grep -m1 -F "$REQUEST_URI	" "$bmfile" |sed -r 's;.*\t;;'))" \
                  "$(l10n bm_del)"
        else
          printf '<input type="hidden" name="bm_url" value="%s" />
                  <input type="text" name="bm_name" placeholder="%s" /
                  ><button type="submit" name="submit" value="add">%s</button>' \
                  "$(attribsafe ${REQUEST_URI})" "$(l10n Bookmark)" "$(l10n bm_add)"
        fi)
      </form>
    </div>
EOF

debug BODY; [ -x "${BODY}" ] && . "${BODY}" || printf %s 'Error'

printf '</body></html>'

# vi:set filetype=html:
